@@ -67,6 +67,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
     let gen = quote! {
         mod checkout_server {
             pub use std::sync::Arc;
+            pub use std::time::Duration;
             pub use checkout_core::dropshot::ApiDescription;
             pub use checkout_core::dropshot::ConfigDropshot;
             pub use checkout_core::dropshot::ConfigLogging;
@@ -487,6 +488,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 let context_provider = checkout_server::Arc::new(self);
 
                 let pubsub_client = internal_context.pubsub_client.clone();
+                pubsub_client.spawn_token_renew(checkout_server::Duration::from_secs(15 * 60));
 
                 checkout_server::HttpServerStarter::new(
                     &checkout_server::ConfigDropshot {
